===============================================
Usage
===============================================
After installation, you can import and use our package in your Python scripts::

    from climalysis import module1, module2

You can now access the functions/classes in these modules.

Contributing
------------

We warmly welcome contributions! Please see `here <CONTRIBUTING.md>`_ for details on how to contribute. Have a look at the discussions if you need any ideas for where to contribute.

License
-------

This project is licensed under the terms of the GNU General Public License. See `LICENSE <LICENSE>`_ for more details.

Contact
-------

If you have any questions, feel free to reach out to us. For major decisions, please consult with our project lead, Jake Casselman (jake.w.casselman@gmail.com).

Acknowledgments
---------------

We would like to express our gratitude to all contributors and users of Climalysis. Your support is greatly appreciated.

Supporters
----------

Climalysis is grateful for the support of the following organizations:

- `ClimaLinks <https://www.climalinks.com>`_: Supported the development of our initial infrastructure and mission statement.

The financial and resource support from these organizations has greatly assisted the development of Climalysis. However, their involvement does not influence the direction, findings, or publications of the project. 

Conflict of Interest
--------------------

We declare that there is no conflict of interest. The direction and goals of Climalysis are determined solely by the project team, independent of any external organizations.